@@ -18,7 +18,7 @@ from .control import ControlSender
 class Client:
     def __init__(
         self,
-        device: Optional[Union[AdbDevice, str]] = None,
+        device: Optional[Union[AdbDevice, str, any]] = None,
         max_width: int = 0,
         bitrate: int = 8000000,
         max_fps: int = 0,
@@ -26,6 +26,7 @@ class Client:
         block_frame: bool = False,
         stay_awake: bool = False,
         lock_screen_orientation: int = LOCK_SCREEN_ORIENTATION_UNLOCKED,
+        connection_timeout: int = 3000,
     ):
         """
         Create a scrcpy client, this client won't be started until you call the start function
@@ -39,6 +40,7 @@ class Client:
             block_frame: only return nonempty frames, may block cv2 render thread
             stay_awake: keep Android device awake
             lock_screen_orientation: lock screen orientation, LOCK_SCREEN_ORIENTATION_*
+            connection_timeout: timeout for connection, unit is ms
         """
 
         if device is None:
@@ -63,6 +65,7 @@ class Client:
         self.block_frame = block_frame
         self.stay_awake = stay_awake
         self.lock_screen_orientation = lock_screen_orientation
+        self.connection_timeout = connection_timeout
 
         # Need to destroy
         self.alive = False
@@ -76,7 +79,7 @@ class Client:
         Connect to android server, there will be two sockets, video and control socket.
         This method will set: video_socket, control_socket, resolution variables
         """
-        for _ in range(30):
+        for _ in range(self.connection_timeout // 100):
             try:
                 self.__video_socket = self.device.create_connection(
                     Network.LOCAL_ABSTRACT, "scrcpy"
@@ -89,7 +92,7 @@ class Client:
             raise ConnectionError("Failed to connect scrcpy-server after 3 seconds")
 
         dummy_byte = self.__video_socket.recv(1)
-        if not len(dummy_byte):
+        if not len(dummy_byte) or dummy_byte != b"\x00":
             raise ConnectionError("Did not receive Dummy Byte!")
 
         self.control_socket = self.device.create_connection(
@@ -107,35 +110,37 @@ class Client:
         """
         Deploy server to android device
         """
-        server_root = os.path.abspath(os.path.dirname(__file__))
-        server_file_path = server_root + "/scrcpy-server.jar"
+        jar_name = "scrcpy-server-v1.24.jar"
+        server_file_path = os.path.join(
+            os.path.abspath(os.path.dirname(__file__)), jar_name
+        )
         self.device.push(server_file_path, "/data/local/tmp/")
-        self.__server_stream = self.device.shell(
-            [
-                "CLASSPATH=/data/local/tmp/scrcpy-server.jar",
-                "app_process",
-                "/",
-                "com.genymobile.scrcpy.Server",
-                "1.20",  # Scrcpy server version
-                "info",  # Log level: info, verbose...
-                f"{self.max_width}",  # Max screen width (long side)
-                f"{self.bitrate}",  # Bitrate of video
-                f"{self.max_fps}",  # Max frame per second
-                f"{self.lock_screen_orientation}",  # Lock screen orientation: LOCK_SCREEN_ORIENTATION
-                "true",  # Tunnel forward
-                "-",  # Crop screen
-                "false",  # Send frame rate to client
-                "true",  # Control enabled
-                "0",  # Display id
-                "false",  # Show touches
-                "true" if self.stay_awake else "false",  # Stay awake
-                "-",  # Codec (video encoding) options
-                "-",  # Encoder name
-                "false",  # Power off screen after server closed
-            ],
+        commands = [
+            f"CLASSPATH=/data/local/tmp/{jar_name}",
+            "app_process",
+            "/",
+            "com.genymobile.scrcpy.Server",
+            "1.24",  # Scrcpy server version
+            "log_level=info",  # Log level: info, verbose...
+            f"bit_rate={self.bitrate}",  # Bitrate of video
+            f"max_size={self.max_width}",  # Max screen width (long side)
+            f"max_fps={self.max_fps}",  # Max frame per second
+            f"lock_video_orientation={self.lock_screen_orientation}",  # Lock screen orientation: LOCK_SCREEN_ORIENTATION
+            "tunnel_forward=true",  # Tunnel forward
+            "control=true",  # Control enabled
+            "display_id=0",  # Display id
+            "show_touches=false",  # Show touches
+            f"stay_awake={str(self.stay_awake).lower()}",  # Stay awake
+            "clipboard_autosync=false",  # Disable Clipboard autosync
+        ]
+        self.__server_stream: _AdbStreamConnection = self.device.shell(
+            commands,
             stream=True,
         )
 
+        # Wait for server to start
+        self.__server_stream.read(10)
+
     def start(self, threaded: bool = False) -> None:
         """
         Start listening video stream
